@@ -580,10 +580,12 @@ purple_proxy_connect_data_destroy(PurpleProxyConnectData *connect_data)
 	while (connect_data->hosts != NULL)
 	{
 		/* Discard the length... */
-		connect_data->hosts = g_slist_remove(connect_data->hosts, connect_data->hosts->data);
+		connect_data->hosts = g_slist_delete_link(connect_data->hosts,
+		                                          connect_data->hosts);
 		/* Free the address... */
 		g_free(connect_data->hosts->data);
-		connect_data->hosts = g_slist_remove(connect_data->hosts, connect_data->hosts->data);
+		connect_data->hosts = g_slist_delete_link(connect_data->hosts,
+		                                          connect_data->hosts);
 	}
 
 	g_free(connect_data->host);
@@ -2061,7 +2063,6 @@ s5_canwrite(gpointer data, gint source, PurpleInputCondition cond)
 		return;
 	}
 
-	i = 0;
 	buf[0] = 0x05;		/* SOCKS version 5 */
 
 	if (purple_proxy_info_get_username(connect_data->gpi) != NULL) {
